import { CharacteristicValue } from "homebridge";
import { Cover } from "shellies-ds9";
import { Ability, ServiceClass } from "./base";
export declare class CoverAbility extends Ability {
    readonly component: Cover;
    readonly type: "door" | "window" | "windowCovering";
    /**
     * @param component - The cover component to control.
     * @param type - The type of cover.
     */
    constructor(component: Cover, type?: "door" | "window" | "windowCovering");
    protected get serviceClass(): ServiceClass;
    /**
     * The current state of the cover.
     */
    protected get positionState(): CharacteristicValue;
    /**
     * The current position of the cover.
     */
    protected get currentPosition(): number;
    /**
     * The target position that the cover is moving towards.
     */
    protected get targetPosition(): number;
    protected initialize(): void;
    detach(): void;
    /**
     * Handles changes to the TargetPosition characteristic.
     */
    protected targetPositionSetHandler(value: CharacteristicValue): Promise<void>;
    /**
     * Handles changes to the `state` property.
     */
    protected stateChangeHandler(): void;
    /**
     * Updates all states.
     *
     * Shelly does not send all attributes in a single notification.
     * We apparently need to update all states when any of them change, otherwise HomeKit
     * gets confused and thinks the cover is in a different state than it actually is.
     */
    protected updateStates(): void;
    /**
     * Handles changes to the `current_pos` property.
     */
    protected currentPosChangeHandler(): void;
    /**
     * Handles changes to the `target_pos` property.
     */
    protected targetPosChangeHandler(): void;
}
//# sourceMappingURL=cover.d.ts.map